OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "正在进行迁移。请稍等，直到迁移完成",
    "Migration started …" : "迁移开始...",
    "Saved" : "已保存",
    "Not saved" : "未保存",
    "Sending…" : "正在发送…",
    "Email sent" : "邮件已发送",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "发生错误。请上传 ASCII 编码的 PEM 证书。",
    "Valid until {date}" : "有效期至 {date}",
    "Delete" : "删除",
    "Local" : "本地",
    "Private" : "私有",
    "Only visible to local users" : "仅对本地用户可见",
    "Only visible to you" : "仅您自己可见",
    "Contacts" : "联系人",
    "Visible to local users and to trusted servers" : "仅对本地用户和信任的服务器可见",
    "Public" : "公开",
    "Will be synced to a global and public address book" : "将同步到全局和公开地址簿中",
    "Verify" : "验证",
    "Verifying …" : "正在验证...",
    "Unable to change password" : "无法修改密码",
    "Very weak password" : "非常弱的密码",
    "Weak password" : "弱密码",
    "So-so password" : "一般强度的密码",
    "Good password" : "较强的密码",
    "Strong password" : "强密码",
    "An error occurred while changing your language. Please reload the page and try again." : "修改您的语言时遇到错误。请重新载入页面后再试。",
    "An error occurred while changing your locale. Please reload the page and try again." : "修改您的地区时遇到错误。请重新载入页面后再试。",
    "Select a profile picture" : "选择个人头像",
    "Week starts on {fdow}" : "周开始于 {fdow}",
    "Groups" : "分组",
    "Group list is empty" : "群组列表为空",
    "Unable to retrieve the group list" : "无法获取分组列表",
    "{actor} added you to group {group}" : "{actor} 将您加入分组 {group}",
    "You added {user} to group {group}" : "您将 {user} 加入分组 {group}",
    "{actor} added {user} to group {group}" : "{actor} 将 {user} 加入分组 {group}",
    "An administrator added you to group {group}" : "一个管理员将您加入分组 {group}",
    "An administrator added {user} to group {group}" : "一个管理员将 {user} 加入分组 {group}",
    "{actor} removed you from group {group}" : "{actor} 将您从分组 {group} 中移除",
    "You removed {user} from group {group}" : "您已将 {user} 从 群组 {group} 中移除",
    "{actor} removed {user} from group {group}" : "{actor} 将 {user} 从分组 {group} 中移除",
    "An administrator removed you from group {group}" : "一个管理员将你从分组 {group} 中移除",
    "An administrator removed {user} from group {group}" : "一个管理员将 {user} 从分组 {group} 中移除",
    "Your <strong>group memberships</strong> were modified" : "您的<strong>分组成员关系</strong>已被修改。",
    "{actor} changed your password" : "{actor} 已更改您的密码",
    "You changed your password" : "您已更改您的密码",
    "Your password was reset by an administrator" : "您的密码已被管理员重置",
    "{actor} changed your email address" : "{actor} 已更改您的电子邮件地址",
    "You changed your email address" : "您已更改您的电子邮件地址",
    "Your email address was changed by an administrator" : "您的电子邮件地址已被管理员更改",
    "You created app password \"{token}\"" : "您创建了应用密码 \"{token}\"",
    "You deleted app password \"{token}\"" : "您删除了应用密码 \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "您将应用密码 \"{token}\" 重命名为 \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "您将文件系统访问权限授予了应用密码 \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "您撤销了应用密码 \"{token}\" 的文件系统访问权限",
    "Security" : "安全",
    "You successfully logged in using two-factor authentication (%1$s)" : "您使用两步验证登录成功（%1$s）",
    "A login attempt using two-factor authentication failed (%1$s)" : "使用两步验证登录失败的尝试 (%1$s)",
    "Remote wipe was started on %1$s" : "%1$s上的远程擦除已开始",
    "Remote wipe has finished on %1$s" : "%1$s上的远程擦除已完成",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "您的 <strong>密码</strong> 或 <strong>邮箱</strong> 已被更改",
    "Couldn't remove app." : "无法删除应用。",
    "Couldn't update app." : "无法更新应用。",
    "Wrong password" : "密码错误",
    "No user supplied" : "没有满足的用户",
    "Authentication error" : "认证错误",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "请提供管理员恢复密码，否则所有用户的数据都将丢失。",
    "Wrong admin recovery password. Please check the password and try again." : "错误的管理员恢复密码。请检查密码并重试。",
    "Backend doesn't support password change, but the user's encryption key was updated." : "后端不支持密码更改，但用户的加密密钥已更新。",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "通过应用程序商店或联合云共享安装和更新应用程序",
    "Federated Cloud Sharing" : "联合云共享",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL正使用一个过时的%1$s 版本 (%2$s)。请升级您的操作系统，否则像 %3$s 这样的特性将无法可靠地工作。",
    "Invalid SMTP password." : "无效的 SMTP 密码",
    "Email setting test" : "电子邮件设置测试",
    "Well done, %s!" : "已完成，%s！",
    "If you received this email, the email configuration seems to be correct." : "如果您收到了这封邮件，电子邮件配置应该就是正确的。",
    "Email could not be sent. Check your mail server log" : "邮件无法发送。检查您的邮件服务器日志",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "在发送电子邮件时出现问题。请修正您的设置。（错误：%s）",
    "You need to set your user email before being able to send test emails." : "在发送测试邮件前您需要设置您的电子邮件地址。",
    "Invalid mail address" : "无效的电子邮件地址",
    "Settings saved" : "设置已保存",
    "Unable to change full name" : "无法修改全名",
    "Unable to change email address" : "无法修改电子邮箱地址",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "为了验证您的 Twitter 帐户，请在 Twitter 上发布以下推文（请确保发布没有任何换行符）：",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "为了验证您的网站，请将以下内容存储在“.well-known / CloudIdVerificationCode.txt”的网络根目录中（请确保完整的文本在一行中）：",
    "%1$s changed your password on %2$s." : "%1$s 更改了您在 %2$s 上的密码。",
    "Your password on %s was changed." : "您在 %s 上的密码已被更改。",
    "Your password on %s was reset by an administrator." : "您在 %s 上的密码已被管理员重置。",
    "Password for %1$s changed on %2$s" : "%2$s %1$s 的密码已更改",
    "Password changed for %s" : "%s 的密码已更改",
    "If you did not request this, please contact an administrator." : "如果这不是您发起的请求，请联系管理员。",
    "Your email address on %s was changed." : "您在 %s 上的电子邮件地址已更改。",
    "Your email address on %s was changed by an administrator." : "您在 %s 上的电子邮件地址已被管理员修改",
    "Email address for %1$s changed on %2$s" : "%2$s 上 %1$s 的电子邮件地址已更改",
    "Email address changed for %s" : "%s 的电子邮件地址已更改",
    "The new email address is %s" : "新的电子邮件地址是%s",
    "Your %s account was created" : "您的 %s 帐户已创建",
    "Welcome aboard" : "欢迎使用",
    "Welcome aboard %s" : "%s，欢迎使用",
    "Welcome to your %s account, you can add, protect, and share your data." : "欢迎使用您的 %s 帐户，您可以添加、保护和共享您的数据。",
    "Your username is: %s" : "您的用户名是：%s",
    "Set your password" : "设置您的密码",
    "Go to %s" : "访问 %s",
    "Install Client" : "安装客户端",
    "Logged in user must be a subadmin" : "当前登录用户必须为子管理员",
    "Create" : "创建",
    "Change" : "修改",
    "Share" : "共享",
    "Unlimited" : "无限",
    "Verifying" : "正在验证",
    "Nextcloud settings" : "Nextcloud设置",
    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "两步验证可以对于所有用户和特定组启用。如果没有设置两步验证方式提供者，他们则不能登录到系统。",
    "Enforce two-factor authentication" : "强制启用两步验证",
    "Limit to groups" : "限制于组",
    "Enforcement of two-factor authentication can be set for certain groups only." : "可以仅为某些组设置两步验证的强制执行。",
    "Two-factor authentication is enforced for all\tmembers of the following groups." : "两步验证对以下分组的所有成员强制启用。",
    "Enforced groups" : "强制群组",
    "Two-factor authentication is not enforced for\tmembers of the following groups." : "两步验证不对以下分组的成员强制启用。",
    "Excluded groups" : "排除群组",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "当分组被选择/排除时，将使用以下逻辑来确定一个用户是否强制启用两步验证：如果没有选择分组，两步验证将对被排除分组成员外的所有用户启用。如果选择了分组，两步验证将对被选择分组的成员启用。如果一个用户同时属于被选择和被排除分组，被选择分组将拥有优先权，两步验证将对该用户强制启用。",
    "Save changes" : "保存修改",
    "This app is supported via your current Nextcloud subscription." : "根据您的Nextcloud订阅，此应用受到支持。",
    "Supported" : "受支持",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "官方应用由社区和内部开发。其可以提供核心功能并保证生产用途。",
    "Official" : "官方",
    "by" : "由",
    "Update to {version}" : "更新至 {version}",
    "Remove" : "移除",
    "Disable" : "禁用",
    "All" : "全部",
    "Limit app usage to groups" : "限制可使用应用的分组",
    "No results" : "没有结果",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最低版本。可能会在将来出现问题。",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "该应用没有指定支持的 Nextcloud 最高版本。可能会在将来出现问题。",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "无法安装应用，因为无法满足下列依赖：",
    "View in store" : "在商店中查看",
    "Visit website" : "访问网站",
    "Report a bug" : "报告问题",
    "User documentation" : "用户文档",
    "Admin documentation" : "管理员文档",
    "Developer documentation" : "开发者文档",
    "Update to {update}" : "更新至 {update}",
    "Results from other categories" : "来自其他类别的结果",
    "No apps found for your version" : "未找到适合当前版本的应用",
    "Disable all" : "禁用全部",
    "Enable all" : "启用所有",
    "Download and enable" : "下载并启用",
    "Enable" : "启用",
    "Enable untested app" : "启用未经测试的应用",
    "The app will be downloaded from the app store" : "该应用将从应用商店下载",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的Nextcloud版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
    "Marked for remote wipe" : "标记为远程擦除",
    "Device settings" : "设备设置",
    "Allow filesystem access" : "允许访问文件系统",
    "Rename" : "重命名",
    "Revoke" : "撤销",
    "Wipe device" : "擦除设备",
    "Revoking this token might prevent the wiping of your device if it hasn't started the wipe yet." : "如果擦除操作还未开始，撤销此令牌可能会妨碍对您设备的擦除操作",
    "Internet Explorer" : "IE 浏览器",
    "Edge" : "Edge 浏览器",
    "Firefox" : "火狐浏览器",
    "Google Chrome" : "谷歌浏览器",
    "Safari" : "Safari 浏览器",
    "Google Chrome for Android" : "安卓版谷歌浏览器",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Nextcloud iOS 应用",
    "Nextcloud Android app" : "Nextcloud Android 应用",
    "Nextcloud Talk for iOS" : "Nextcloud Talk for iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk for Android",
    "Sync client - {os}" : "同步客户端 - {os}",
    "This session" : "当前会话",
    "Device" : "设备",
    "Last activity" : "最后活跃",
    "Devices & sessions" : "设备和活动链接",
    "Web, desktop and mobile clients currently logged in to your account." : "您账号当前登录的 Web 页面，桌面和移动客户端。",
    "Do you really want to wipe your data from this device?" : "您真的要从此设备擦除您的数据吗？",
    "Confirm wipe" : "确认擦除",
    "Error while creating device token" : "创建设备令牌时出错",
    "Error while updating device token scope" : "更新设备令牌范围时出错",
    "Error while updating device token name" : "更新设备令牌名称时出错",
    "Error while deleting the token" : "删除令牌时出错",
    "Error while wiping the device with the token" : "使用令牌擦除设备时出错",
    "App name" : "应用名",
    "Create new app password" : "创建新应用密码",
    "Use the credentials below to configure your app or device." : "使用下述凭据配置您的应用或设备。",
    "For security reasons this password will only be shown once." : "由于安全原因，密码仅会显示一次。",
    "Username" : "用户名",
    "Password" : "密码",
    "Done" : "完成",
    "Show QR code for mobile apps" : "为移动应用展示QR二维码",
    "Copied!" : "已复制！",
    "Copy" : "复制",
    "Could not copy app password. Please copy it manually." : "无法复制应用密码。请手动复制。",
    "You do not have permissions to see the details of this user" : "您没有权限查看该用户的详细信息",
    "The backend does not support changing the display name" : "此后端不支持修改显示名称",
    "New password" : "新密码",
    "Add user in group" : "向群组中添加用户",
    "Set user as admin for" : "设置用户为管理员",
    "Select user quota" : "选择用户容量限额",
    "No language set" : "没有设置语言",
    "Never" : "从不",
    "Delete user" : "删除用户",
    "Wipe all devices" : "擦除所有设备",
    "Disable user" : "禁用用户",
    "Enable user" : "启用用户",
    "Resend welcome email" : "重新发送欢迎邮件",
    "{size} used" : "{size} 已使用",
    "Welcome mail sent!" : "欢迎邮件已经发送！",
    "Display name" : "显示名称",
    "Email" : "电子邮件",
    "Group admin for" : "分组管理员",
    "Quota" : "配额",
    "Language" : "语言",
    "Storage location" : "存储位置",
    "User backend" : "用户来源",
    "Last login" : "最后登录",
    "Will be autogenerated" : "将自动生成",
    "Default language" : "默认语言",
    "Add a new user" : "添加新用户",
    "No users in here" : "这里没有用户",
    "Default quota" : "默认配额",
    "Common languages" : "常用语言",
    "All languages" : "所有语言",
    "Password change is disabled because the master key is disabled" : "密码修改被禁用，因为主密码被禁用",
    "Your apps" : "您的应用",
    "Active apps" : "已启用的应用",
    "Disabled apps" : "已禁用的应用",
    "Updates" : "更新",
    "App bundles" : "应用软件包",
    "{license}-licensed" : "{license}-许可协议",
    "New user" : "新建用户",
    "Default quota:" : "默认配额：",
    "Select default quota" : "选择默认存储限额",
    "Show Languages" : "显示语言",
    "Show last login" : "显示最后登录",
    "Show user backend" : "显示用户来源",
    "Show storage path" : "显示存储路径",
    "Remove group" : "删除分组",
    "Admins" : "管理员",
    "Disabled users" : "已禁用的用户",
    "Everyone" : "所有人",
    "Add group" : "添加分组",
    "You are about to remove the group {group}. The users will NOT be deleted." : "您正在删除 {group} 组。组中的用户将不会被删除。",
    "Please confirm the group removal " : "请确认分组删除",
    "An error occured during the request. Unable to proceed." : "请求期间发生错误。 无法继续。",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。5秒后将跳转到更新页面。",
    "App update" : "更新应用",
    "Error: This app can not be enabled because it makes the server unstable" : "错误：无法启用应用因为它会导致服务器不稳定",
    "SSL Root Certificates" : "SSL 根证书",
    "Common Name" : "通用名称",
    "Valid until" : "有效期至",
    "Issued By" : "授权由",
    "Valid until %s" : "有效期至 %s",
    "Import root certificate" : "导入根证书",
    "Administrator documentation" : "管理员文档",
    "Documentation" : "文档",
    "Forum" : "论坛",
    "None" : "无",
    "Login" : "登录",
    "Plain" : "明文",
    "NT LAN Manager" : "NT LAN 管理器",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "电子邮件服务器",
    "Open documentation" : "打开文档",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "设置此服务器以能够发送电子邮件（例如密码重置和通知）非常重要。",
    "Send mode" : "发送模式",
    "Encryption" : "加密",
    "Sendmail mode" : "邮件发送模式",
    "From address" : "来自地址",
    "mail" : "邮件",
    "Authentication method" : "认证方法",
    "Authentication required" : "需要认证",
    "Server address" : "服务器地址",
    "Port" : "端口",
    "Credentials" : "凭证",
    "SMTP Username" : "SMTP 用户名",
    "SMTP Password" : "SMTP 密码",
    "Save" : "保存",
    "Test email settings" : "测试电子邮件设置",
    "Send email" : "发送邮件",
    "Security & setup warnings" : "安全及设置警告",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "您的每项配置对于实例的安全性和性能都至关重要。 为了帮助您，我们正在做一些自动检查。 有关详细信息，请参阅文档链接。",
    "All checks passed." : "所有检查已通过。",
    "There are some errors regarding your setup." : "关于您的设置有一些错误。",
    "There are some warnings regarding your setup." : "关于您的设置有一些警告。",
    "Checking for system and security issues." : "正在检查系统和安全问题。",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "请仔细检查<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">安装指南↗</a>，并检查<a href=\"%2$s\">日志</a>中是否有错误或警告。",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "通过<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">我们的安全检查 ↗</a>检查您 Nextcloud 的安全",
    "Version" : "版本",
    "Two-Factor Authentication" : "两步验证",
    "Server-side encryption" : "服务器端加密",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "服务器端加密可以加密上传到此服务器的文件。这带来了诸如性能损失的限制，因此仅在需要时启用此功能。",
    "Enable server-side encryption" : "启用服务器端加密",
    "Please read carefully before activating server-side encryption: " : "在激活服务器端加密之前，请仔细阅读：",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "一旦加密被启用，之后上传到服务器的所有文件都将服务器上加密。只有当启用状态的加密模块支持解密并且所有前提都满足时（例如：设定恢复密钥）才能解除加密。",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "单独的加密不能保证系统的安全性。请参考加密应用工作原理和支持的用例的文档获取更多信息。",
    "Be aware that encryption always increases the file size." : "请注意，加密会增加文件大小。",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "定期备份数据有助于保证数据完整，并且确保备份您的加密数据和加密密钥。",
    "This is the final warning: Do you really want to enable encryption?" : "这是最后一次警告：您确定要启用加密？",
    "Enable encryption" : "启用加密",
    "No encryption module loaded, please enable an encryption module in the app menu." : "没有加载加密模块，请在 APP 应用菜单中启用加密模块。",
    "Select default encryption module:" : "选择默认的加密模块：",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "您需要从旧版本（ownCloud <= 8.0）迁移您的加密密钥。请在应用中启用 \\\"Default encryption module\\\" 并运行 'occ encryption:migrate'",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "您需要从旧版本（ownCloud<=8.0）迁移您的加密密钥。",
    "Start migration" : "开始迁移",
    "Background jobs" : "后台任务",
    "Last job ran %s." : "上次定时任务执行于：%s。",
    "Last job execution ran %s. Something seems wrong." : "上次定时任务执行于：%s。但存在一些问题。",
    "Background job didn’t run yet!" : "后台任务当前没有运行！",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "为了优化性能，正确配置后台任务非常重要。对于较大的实例，推荐配置为 'Cron'。详情请参考相关文档。",
    "Pick background job setting" : "选择后台任务设置",
    "Execute one task with each page loaded" : "每个页面加载后执行一个任务",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP." : "cron.php注册到 webcron 服务上，每5分钟通过HTTP执行一次cron.php。",
    "Use system cron service to call the cron.php file every 5 minutes." : "使用系统定时任务服务每5分钟执行一次cron.php文件。",
    "The cron.php needs to be executed by the system user \"%s\"." : "cron.php 需要被系统用户 \"%s\" 执行。",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "为了运行该功能，您需要 PHP posix 扩展。请参考 {linkstart}PHP 文档{linkend} 获取更多信息。",
    "Sharing" : "共享",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "作为管理员，您可以调整共享行为。 有关详细信息，请参阅文档。",
    "Allow apps to use the Share API" : "允许应用使用共享 API",
    "Allow users to share via link" : "允许用户通过链接共享文件",
    "Allow public uploads" : "允许公开上传",
    "Always ask for a password" : "一直要求输入密码",
    "Enforce password protection" : "强制密码保护",
    "Set default expiration date" : "设置默认过期日期",
    "Expire after " : "过期于",
    "days" : "天",
    "Enforce expiration date" : "强制过期日期",
    "Allow resharing" : "允许二次共享",
    "Allow sharing with groups" : "允许群组共享",
    "Restrict users to only share with users in their groups" : "限制仅与组内用户共享",
    "Exclude groups from sharing" : "在共享中排除组",
    "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取共享，但无法向他人共享。",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "在共享对话框中允许用户名自动完成。 如果被禁用，则需要输入完整的用户名或电子邮件地址。",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "在公开链接上传页中显示免责声明。（仅当文件列表隐藏时显示。）",
    "This text will be shown on the public link upload page when the file list is hidden." : "这些内容将在公开链接上传页中当文件列表隐藏时显示。",
    "Default share permissions" : "默认共享权限",
    "Personal" : "个人",
    "Administration" : "管理",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由 {communityopen}Nextcloud community{linkclose} 开发，{githubopen}源代码{linkclose} 基于 {licenseopen}AGPL{linkclose} 许可协议。",
    "Like our Facebook page" : "点赞我们 facebook 页面！",
    "Follow us on Twitter" : "在 Twitter 上关注我们！",
    "Follow us on Mastodon" : "在Mastodon上关注我们",
    "Check out our blog" : "浏览我们的博客！",
    "Subscribe to our newsletter" : "订阅我们的最新消息！",
    "Profile picture" : "个人头像",
    "Upload new" : "上传",
    "Select from Files" : "选择文件",
    "Remove image" : "删除图片",
    "png or jpg, max. 20 MB" : "png 或 jpg 格式，最大 20MB",
    "Picture provided by original account" : "初始账号提供的图片",
    "Cancel" : "取消",
    "Choose as profile picture" : "选择个人头像",
    "Details" : "详情",
    "You are a member of the following groups:" : "您是以下群组的成员：",
    "You are using <strong>%s</strong>" : "您正在使用<strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "您正在使用 <strong>%1$s</strong> ，来自 <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "全名",
    "No display name set" : "不显示名称设置",
    "Your email address" : "您的电子邮件",
    "No email address set" : "尚未设置 Email 地址",
    "For password reset and notifications" : "用于密码重置和通知",
    "Phone number" : "电话号码",
    "Your phone number" : "您的电话号码",
    "Address" : "地址",
    "Your postal address" : "您的邮寄地址",
    "Website" : "网站",
    "It can take up to 24 hours before the account is displayed as verified." : "在帐户显示为验证之前最多可能需要24小时。",
    "Link https://…" : "链接 https://…",
    "Twitter" : "推特",
    "Twitter handle @…" : "推特用户名@…",
    "Help translate" : "帮助翻译",
    "Locale" : "本地",
    "Current password" : "当前密码",
    "Change password" : "修改密码",
    "Use a second factor besides your password to increase security for your account." : "使用除您密码之外的第二种方法来增强您账号的安全性。",
    "Disconnect" : "断开连接",
    "Not supported!" : "不支持！",
    "Press ⌘-C to copy." : "按 ⌘-C 复制。",
    "Press Ctrl-C to copy." : "按 Ctrl-C 复制。",
    "Error while loading browser sessions and device tokens" : "加载浏览器会话和设备令牌时出错",
    "Afrikaans (Namibia)" : "南非语（纳米比亚）",
    "Afrikaans (South Africa)" : "南非语（南非）",
    "Afrikaans" : "南非语",
    "Akan (Ghana)" : "阿肯语（加纳）",
    "Akan" : "阿肯语",
    "Albanian (Albania)" : "阿尔巴尼亚语（阿尔巴尼亚）",
    "Albanian" : "阿尔巴尼亚语",
    "Amharic (Ethiopia)" : "阿姆哈拉语（埃塞俄比亚）",
    "Amharic" : "阿姆哈拉语",
    "Arabic (Algeria)" : "阿拉伯语（阿尔及利亚）",
    "Arabic (Bahrain)" : "阿拉伯语（巴林）",
    "Arabic (Egypt)" : "阿拉伯语（埃及）",
    "Arabic (Iraq)" : "阿拉伯语（伊拉克）",
    "Arabic (Jordan)" : "阿拉伯语（约旦）",
    "Arabic (Kuwait)" : "阿拉伯语（科威特）",
    "Arabic (Lebanon)" : "阿拉伯语（黎巴嫩）",
    "Arabic (Libya)" : "阿拉伯语（利比亚）",
    "Arabic (Morocco)" : "阿拉伯语（摩洛哥）",
    "Arabic (Oman)" : "阿拉伯语（阿曼）",
    "Arabic (Qatar)" : "阿拉伯语（卡塔尔）",
    "Arabic (Saudi Arabia)" : "阿拉伯语（沙特阿拉伯）",
    "Arabic (Sudan)" : "阿拉伯语（苏丹）",
    "Arabic (Syria)" : "阿拉伯语（叙利亚）",
    "Arabic (Tunisia)" : "阿拉伯语（突尼斯）",
    "Arabic (United Arab Emirates)" : "阿拉伯语（阿联酋）",
    "Arabic (Yemen)" : "阿拉伯语（也门）",
    "Arabic" : "阿拉伯语",
    "Armenian (Armenia)" : "亚美尼亚语（亚美尼亚）",
    "Armenian" : "亚美尼亚",
    "Assamese (India)" : "阿萨姆语（印度）",
    "Assamese" : "阿萨姆语",
    "Asu (Tanzania)" : "阿苏语（坦桑尼亚）",
    "Asu" : "阿苏语",
    "Azerbaijani (Cyrillic)" : "阿塞拜疆语（西里尔文）",
    "Azerbaijani (Cyrillic, Azerbaijan)" : "阿塞拜疆语（西里尔文，阿塞拜疆）",
    "Azerbaijani (Latin)" : "阿塞拜疆语（拉丁文）",
    "Azerbaijani (Latin, Azerbaijan)" : "阿塞拜疆语（拉丁文，阿塞拜疆）",
    "Azerbaijani" : "阿塞拜疆语",
    "Bambara (Mali)" : "班巴拉语（马里）",
    "Bambara" : "班巴拉语",
    "Basque (Spain)" : "巴斯克语（西班牙）",
    "Basque" : "巴斯克语",
    "Belarusian (Belarus)" : "白俄罗斯语（白俄罗斯）",
    "Belarusian" : "白俄罗斯语",
    "Bemba (Zambia)" : "本巴语（赞比亚）",
    "Bemba" : "本巴语",
    "Bena (Tanzania)" : "贝纳语（坦桑尼亚）",
    "Bena" : "贝纳语",
    "Bengali (Bangladesh)" : "孟加拉语（孟加拉国）",
    "Bengali (India)" : "孟加拉语（印度）",
    "Bengali" : "孟加拉语",
    "Bosnian (Bosnia and Herzegovina)" : "波斯尼亚语（波黑）",
    "Bosnian" : "波斯尼亚语",
    "Bulgarian (Bulgaria)" : "保加利亚语（保加利亚）",
    "Bulgarian" : "保加利亚语",
    "Burmese (Myanmar [Burma])" : "缅甸语（缅甸［缅甸］）",
    "Burmese" : "缅甸语",
    "Catalan (Spain)" : "加泰罗尼亚语（西班牙）",
    "Catalan" : "加泰罗尼亚语",
    "Central Morocco Tamazight (Latin)" : "中摩洛哥柏柏尔语（拉丁文）",
    "Central Morocco Tamazight (Latin, Morocco)" : "中摩洛哥柏柏尔语（拉丁文，摩洛哥）",
    "Central Morocco Tamazight" : "中摩洛哥柏柏尔语",
    "Cherokee (United States)" : "切诺基语（美国）",
    "Cherokee" : "切诺基语",
    "Chiga (Uganda)" : "奇加语（乌干达）",
    "Chiga" : "奇加语",
    "Chinese (Simplified Han)" : "中文（简体）",
    "Chinese (Simplified Han, China)" : "中文（简体，中国）",
    "Chinese (Simplified Han, Hong Kong SAR China)" : "中文（简体，中国香港特别行政区）",
    "Chinese (Simplified Han, Macau SAR China)" : "中文（简体，中国澳门特别行政区）",
    "Chinese (Simplified Han, Singapore)" : "中文（简体，新加坡）",
    "Chinese (Traditional Han)" : "中文（繁体）",
    "Chinese (Traditional Han, Hong Kong SAR China)" : "中文（繁体，中国香港特别行政区）",
    "Chinese (Traditional Han, Macau SAR China)" : "中文（繁体，中国澳门特别行政区）",
    "Chinese (Traditional Han, Taiwan)" : "中文（繁体，台湾）",
    "Chinese" : "中文",
    "Cornish (United Kingdom)" : "康沃尔语（英国）",
    "Cornish" : "康沃尔语",
    "Croatian (Croatia)" : "克罗地亚语（克罗地亚）",
    "Croatian" : "克罗地亚语",
    "Czech (Czech Republic)" : "捷克语（捷克共和国）",
    "Czech" : "捷克语",
    "Danish (Denmark)" : "丹麦语（丹麦）",
    "Danish" : "丹麦语",
    "Dutch (Belgium)" : "荷兰语（比利时）",
    "Dutch (Netherlands)" : "荷兰语（荷兰）",
    "Dutch" : "荷兰语",
    "Embu (Kenya)" : "恩布语（肯尼亚）",
    "Embu" : "恩布语",
    "English (American Samoa)" : "英语（美属萨摩亚）",
    "English (Australia)" : "英语（澳大利亚）",
    "English (Belgium)" : "英语（比利时）",
    "English (Belize)" : "英语（伯利兹）",
    "English (Botswana)" : "英语（博茨瓦纳）",
    "English (Canada)" : "英语（加拿大）",
    "English (Guam)" : "英语（关岛）",
    "English (Hong Kong SAR China)" : "英语（中国香港特别行政区）",
    "English (India)" : "英语（印度）",
    "English (Ireland)" : "英语（爱尔兰）",
    "English (Jamaica)" : "英语（牙买加）",
    "English (Malta)" : "英语（马耳他）",
    "English (Marshall Islands)" : "英语（马绍尔群岛）",
    "English (Mauritius)" : "英语（毛里求斯）",
    "English (Namibia)" : "英语（纳米比亚）",
    "English (New Zealand)" : "英语（新西兰）",
    "English (Northern Mariana Islands)" : "英语（北马里亚纳群岛）",
    "English (Pakistan)" : "英语（巴基斯坦）",
    "English (Philippines)" : "英语（菲律宾）",
    "English (Singapore)" : "英语（新加坡）",
    "English (South Africa)" : "英语（南非）",
    "English (Trinidad and Tobago)" : "英语（特立尼达和多巴哥）",
    "English (U.S. Minor Outlying Islands)" : "英语（美国本土外小岛屿）",
    "English (U.S. Virgin Islands)" : "英语（美属维尔京群岛）",
    "English (United Kingdom)" : "英语（英国）",
    "English (United States)" : "英语（美国）",
    "English (Zimbabwe)" : "英语（津巴布韦）",
    "English" : "英语",
    "Esperanto" : "世界语",
    "Estonian (Estonia)" : "爱沙尼亚语（爱沙尼亚）",
    "Estonian" : "爱沙尼亚语",
    "Ewe (Ghana)" : "艾韦语（加纳）",
    "Ewe (Togo)" : "艾韦语（多哥）",
    "Ewe" : "艾韦语",
    "Faroese (Faroe Islands)" : "法罗语（法罗群岛）",
    "Faroese" : "法罗语",
    "Filipino (Philippines)" : "菲律宾语（菲律宾）",
    "Filipino" : "菲律宾语",
    "Finnish (Finland)" : "芬兰语（芬兰）",
    "Finnish" : "芬兰语",
    "French (Belgium)" : "法语（比利时）",
    "French (Benin)" : "法语（贝宁）",
    "French (Burkina Faso)" : "法语（布基纳法索）",
    "French (Burundi)" : "法语（布隆迪）",
    "French (Cameroon)" : "法语（喀麦隆）",
    "French (Canada)" : "法语（加拿大）",
    "French (Central African Republic)" : "法语（中非共和国）",
    "French (Chad)" : "法语（乍得）",
    "French (Comoros)" : "法语（科摩罗）",
    "French (Congo - Brazzaville)" : "法语（刚果-布拉柴维尔）",
    "French (Congo - Kinshasa)" : "法语（刚果-金沙萨）",
    "French (Côte d’Ivoire)" : "法语（科特迪瓦）",
    "French (Djibouti)" : "法语（吉布提）",
    "French (Equatorial Guinea)" : "法语（赤道几内亚）",
    "French (France)" : "法语（法国）",
    "French (Gabon)" : "法语（加蓬）",
    "French (Guadeloupe)" : "法语（瓜德罗普）",
    "French (Guinea)" : "法语（几内亚）",
    "French (Luxembourg)" : "法语（卢森堡）",
    "French (Madagascar)" : "法语（马达加斯加）",
    "French (Mali)" : "法语（马里）",
    "French (Martinique)" : "法语（马提尼克）",
    "French (Monaco)" : "法语（摩纳哥）",
    "French (Niger)" : "法语（尼日尔）",
    "French (Rwanda)" : "法语（卢旺达）",
    "French (Réunion)" : "法语（Réunion）",
    "French (Saint Barthélemy)" : "法语（圣巴泰勒米）",
    "French (Saint Martin)" : "法语（圣马丁）",
    "French (Senegal)" : "法语（塞内加尔）",
    "French (Switzerland)" : "法语（瑞士）",
    "French (Togo)" : "法语（多哥）",
    "French" : "法语",
    "Fulah (Senegal)" : "富拉语（塞内加尔）",
    "Fulah" : "富拉语",
    "Galician (Spain)" : "加利西亚语（西班牙）",
    "Galician" : "加利西亚语",
    "Ganda (Uganda)" : "干达语（乌干达）",
    "Ganda" : "干达语",
    "Georgian (Georgia)" : "格鲁吉亚语（格鲁吉亚）",
    "Georgian" : "格鲁吉亚语",
    "German (Austria)" : "德语（奥地利）",
    "German (Belgium)" : "德语（比利时）",
    "German (Germany)" : "德语（德国）",
    "German (Liechtenstein)" : "德语（列支敦士登）",
    "German (Luxembourg)" : "德语（卢森堡）",
    "German (Switzerland)" : "德语（瑞士）",
    "German" : "德语",
    "Greek (Cyprus)" : "希腊语（赛浦路斯）",
    "Greek (Greece)" : "希腊语（希腊）",
    "Greek" : "希腊语",
    "Gujarati (India)" : "古吉拉特语（印度）",
    "Gujarati" : "古吉拉特语",
    "Gusii (Kenya)" : "古斯利语（肯尼亚）",
    "Gusii" : "古斯利语",
    "Hausa (Latin)" : "豪萨语（拉丁文）",
    "Hausa (Latin, Ghana)" : "豪萨语（拉丁文，加纳）",
    "Hausa (Latin, Niger)" : "豪萨语（拉丁文，尼日尔）",
    "Hausa (Latin, Nigeria)" : "豪萨语（拉丁文，尼日利亚）",
    "Hausa" : "豪萨语",
    "Hawaiian (United States)" : "夏威夷语（美国）",
    "Hawaiian" : "夏威夷语",
    "Hebrew (Israel)" : "希伯来语（以色列）",
    "Hebrew" : "希伯来语",
    "Hindi (India)" : "印地语（印度）",
    "Hindi" : "印地语",
    "Hungarian (Hungary)" : "匈牙利语（匈牙利）",
    "Hungarian" : "匈牙利语",
    "Icelandic (Iceland)" : "冰岛语（冰岛）",
    "Icelandic" : "冰岛语",
    "Igbo (Nigeria)" : "伊博语（尼日利亚）",
    "Igbo" : "伊博语",
    "Indonesian (Indonesia)" : "印度尼西亚语（印度尼西亚）",
    "Indonesian" : "印度尼西亚语",
    "Irish (Ireland)" : "爱尔兰语（爱尔兰）",
    "Irish" : "爱尔兰语",
    "Italian (Italy)" : "意大利语（意大利）",
    "Italian (Switzerland)" : "意大利语（瑞士）",
    "Italian" : "意大利语",
    "Japanese (Japan)" : "日语（日本）",
    "Japanese" : "日语",
    "Kabuverdianu (Cape Verde)" : "Kabuverdianu语（佛得角）",
    "Kabuverdianu" : "Kabuverdianu语",
    "Kabyle (Algeria)" : "卡拜尔语（阿尔及利亚）",
    "Kabyle" : "卡拜尔语",
    "Kalaallisut (Greenland)" : "格陵兰语（格陵兰）",
    "Kalaallisut" : "格陵兰语",
    "Kalenjin (Kenya)" : "卡伦津语（肯尼亚）",
    "Kalenjin" : "卡伦津语",
    "Kamba (Kenya)" : "坎巴语（肯尼亚）",
    "Kamba" : "坎巴语",
    "Kannada (India)" : "坎纳德语（印度）",
    "Kannada" : "坎纳德语",
    "Kazakh (Cyrillic)" : "哈萨克语（西里尔文）",
    "Kazakh (Cyrillic, Kazakhstan)" : "哈萨克语（西里尔文，哈萨克斯坦）",
    "Kazakh" : "哈萨克语",
    "Khmer (Cambodia)" : "高棉语（柬埔寨）",
    "Khmer" : "高棉语",
    "Kikuyu (Kenya)" : "基库尤语（肯尼亚）",
    "Kikuyu" : "基库尤语",
    "Kinyarwanda (Rwanda)" : "卢旺达语（卢旺达）",
    "Kinyarwanda" : "卢旺达语",
    "Konkani (India)" : "孔卡尼语（印度）",
    "Konkani" : "孔卡尼语",
    "Korean (South Korea)" : "朝鲜语（南朝鲜）",
    "Korean" : "朝鲜语",
    "Koyra Chiini (Mali)" : "Koyra Chiini语（马里）",
    "Koyra Chiini" : "Koyra Chiini语",
    "Koyraboro Senni (Mali)" : "Koyraboro Senni语（马里）",
    "Koyraboro Senni" : "Koyraboro Senni语",
    "Langi (Tanzania)" : "兰吉语（坦桑尼亚）",
    "Langi" : "兰吉语",
    "Latvian (Latvia)" : "拉脱维亚语（拉脱维亚）",
    "Latvian" : "拉脱维亚语",
    "Lithuanian (Lithuania)" : "立陶宛语（立陶宛）",
    "Lithuanian" : "立陶宛语",
    "Luo (Kenya)" : "罗语（肯尼亚）",
    "Luo" : "罗语",
    "Luyia (Kenya)" : "Luyia语（肯尼亚）",
    "Luyia" : "Luyia语",
    "Macedonian (Macedonia)" : "马其顿语（马其顿）",
    "Macedonian" : "马其顿语",
    "Machame (Tanzania)" : "Machame语（坦桑尼亚）",
    "Machame" : "Machame语",
    "Makonde (Tanzania)" : "马孔达语（坦桑尼亚）",
    "Makonde" : "马孔达语",
    "Malagasy (Madagascar)" : "马尔加什语（马达加斯加）",
    "Malagasy" : "马尔加什语",
    "Malay (Brunei)" : "马来语（文莱）",
    "Malay (Malaysia)" : "马来语（马来西亚）",
    "Malay" : "马来语",
    "Malayalam (India)" : "Malayalam语（印度）",
    "Malayalam" : "Malayalam语",
    "Maltese (Malta)" : "马耳他语（马耳他）",
    "Maltese" : "马耳他语",
    "Manx (United Kingdom)" : "曼克斯语（英国）",
    "Manx" : "曼克斯语",
    "Marathi (India)" : "马拉地语（印度）",
    "Marathi" : "马拉地语",
    "Masai (Kenya)" : "马赛语（肯尼亚）",
    "Masai (Tanzania)" : "马赛语（坦桑尼亚）",
    "Masai" : "马赛语",
    "Meru (Kenya)" : "梅鲁语（肯尼亚）",
    "Meru" : "梅鲁语",
    "Morisyen (Mauritius)" : "Morisyen语（毛里求斯）",
    "Morisyen" : "Morisyen语",
    "Nama (Namibia)" : "那马语（纳米比亚）",
    "Nama" : "那马语",
    "Nepali (India)" : "尼泊尔语（印度）",
    "Nepali (Nepal)" : "尼泊尔语（尼泊尔）",
    "Nepali" : "尼泊尔语",
    "North Ndebele (Zimbabwe)" : "北恩德贝勒语（津巴布韦）",
    "North Ndebele" : "北恩德贝勒语",
    "Norwegian Bokmål (Norway)" : "挪威Bokmål语（挪威）",
    "Norwegian Bokmål" : "挪威Bokmål语",
    "Norwegian Nynorsk (Norway)" : "挪威Nynorsk语（挪威）",
    "Norwegian Nynorsk" : "挪威Nynorsk语",
    "Nyankole (Uganda)" : "尼扬科勒语（乌干达）",
    "Nyankole" : "尼扬科勒语",
    "Oriya (India)" : "奥里亚语（印度）",
    "Oriya" : "奥里亚语",
    "Oromo (Ethiopia)" : "奥罗莫语（埃塞俄比亚）",
    "Oromo (Kenya)" : "奥罗莫语（肯尼亚）",
    "Oromo" : "奥罗莫语",
    "Pashto (Afghanistan)" : "普什图语（阿富汗）",
    "Pashto" : "普什图语",
    "Persian (Afghanistan)" : "波斯语（阿富汗）",
    "Persian (Iran)" : "波斯语（伊朗）",
    "Persian" : "波斯语",
    "Polish (Poland)" : "波兰语（波兰）",
    "Polish" : "波兰语",
    "Portuguese (Brazil)" : "葡萄牙语（巴西）",
    "Portuguese (Guinea-Bissau)" : "葡萄牙语（几内亚-比绍）",
    "Portuguese (Mozambique)" : "葡萄牙语（莫桑比克）",
    "Portuguese (Portugal)" : "葡萄牙语（葡萄牙）",
    "Portuguese" : "葡萄牙语",
    "Punjabi (Arabic)" : "旁遮普语（阿拉伯文）",
    "Punjabi (Arabic, Pakistan)" : "旁遮普语（阿拉伯文，巴基斯坦）",
    "Punjabi (Gurmukhi)" : "旁遮普语（古尔穆基文）",
    "Punjabi (Gurmukhi, India)" : "旁遮普语（古尔穆基文，印度）",
    "Punjabi" : "旁遮普语",
    "Romanian (Moldova)" : "罗马尼亚语（摩尔多瓦）",
    "Romanian (Romania)" : "罗马尼亚语（罗马尼亚）",
    "Romanian" : "罗马尼亚语",
    "Romansh (Switzerland)" : "罗曼什语（瑞士）",
    "Romansh" : "罗曼什语",
    "Rombo (Tanzania)" : "龙博语（坦桑尼亚）",
    "Rombo" : "龙博语",
    "Russian (Moldova)" : "俄语（摩尔多瓦）",
    "Russian (Russia)" : "俄语（俄罗斯）",
    "Russian (Ukraine)" : "俄语（乌克兰）",
    "Russian" : "俄语",
    "Rwa (Tanzania)" : "Rwa语（坦桑尼亚）",
    "Rwa" : "Rwa语",
    "Samburu (Kenya)" : "桑布鲁语（肯尼亚）",
    "Samburu" : "桑布鲁语",
    "Sango (Central African Republic)" : "桑戈语（中非共和国）",
    "Sango" : "桑戈语",
    "Sena (Mozambique)" : "塞纳语（莫桑比克）",
    "Sena" : "塞纳语",
    "Serbian (Cyrillic)" : "塞尔维亚语（西里尔文）",
    "Serbian (Cyrillic, Bosnia and Herzegovina)" : "塞尔维亚语（西里尔文，波黑）",
    "Serbian (Cyrillic, Montenegro)" : "塞尔维亚语（西里尔文，黑山）",
    "Serbian (Cyrillic, Serbia)" : "塞尔维亚语（西里尔文，塞尔维亚）",
    "Serbian (Latin)" : "塞尔维亚语（拉丁文）",
    "Serbian (Latin, Bosnia and Herzegovina)" : "塞尔维亚语（拉丁文，波黑）",
    "Serbian (Latin, Montenegro)" : "塞尔维亚语（拉丁文，黑山）",
    "Serbian (Latin, Serbia)" : "塞尔维亚语（拉丁文，塞尔维亚）",
    "Serbian" : "塞尔维亚语",
    "Shona (Zimbabwe)" : "绍纳语（津巴布韦）",
    "Shona" : "绍纳语",
    "Sichuan Yi (China)" : "四川彝语（中国）",
    "Sichuan Yi" : "四川彝语",
    "Sinhala (Sri Lanka)" : "僧伽罗语（斯里兰卡）",
    "Sinhala" : "僧伽罗语",
    "Slovak (Slovakia)" : "斯洛伐克语（斯洛伐克）",
    "Slovak" : "斯洛伐克语",
    "Slovenian (Slovenia)" : "斯洛文尼亚语（斯洛文尼亚）",
    "Slovenian" : "斯洛文尼亚语",
    "Soga (Uganda)" : "索加语（乌干达）",
    "Soga" : "索加语",
    "Somali (Djibouti)" : "索马里语（吉布提）",
    "Somali (Ethiopia)" : "索马里语（埃塞俄比亚）",
    "Somali (Kenya)" : "索马里语（肯尼亚）",
    "Somali (Somalia)" : "索马里语（索马里）",
    "Somali" : "索马里语",
    "Spanish (Argentina)" : "西班牙语（阿根廷）",
    "Spanish (Bolivia)" : "西班牙语（玻利维亚）",
    "Spanish (Chile)" : "西班牙语（智利）",
    "Spanish (Colombia)" : "西班牙语（哥伦比亚）",
    "Spanish (Costa Rica)" : "西班牙语（哥斯达黎加）",
    "Spanish (Dominican Republic)" : "西班牙语（多米尼克共和国）",
    "Spanish (Ecuador)" : "西班牙语（厄瓜多尔）",
    "Spanish (El Salvador)" : "西班牙语（萨尔瓦多）",
    "Spanish (Equatorial Guinea)" : "西班牙语（赤道几内亚）",
    "Spanish (Guatemala)" : "西班牙语（危地马拉）",
    "Spanish (Honduras)" : "西班牙语（洪都拉斯）",
    "Spanish (Latin America)" : "西班牙语（拉丁美洲）",
    "Spanish (Mexico)" : "西班牙语（墨西哥）",
    "Spanish (Nicaragua)" : "西班牙语（尼加拉瓜）",
    "Spanish (Panama)" : "西班牙语（巴拿马）",
    "Spanish (Paraguay)" : "西班牙语（巴拉圭）",
    "Spanish (Peru)" : "西班牙语（秘鲁）",
    "Spanish (Puerto Rico)" : "西班牙语（波多黎各）",
    "Spanish (Spain)" : "西班牙语（西班牙）",
    "Spanish (United States)" : "西班牙语（美国）",
    "Spanish (Uruguay)" : "西班牙语（乌拉圭）",
    "Spanish (Venezuela)" : "西班牙语（委内瑞拉）",
    "Spanish" : "西班牙语",
    "Swahili (Kenya)" : "斯瓦希里语（肯尼亚）",
    "Swahili (Tanzania)" : "斯瓦希里语（坦桑尼亚）",
    "Swahili" : "斯瓦希里语",
    "Swedish (Finland)" : "瑞典语（芬兰）",
    "Swedish (Sweden)" : "瑞典语（瑞典）",
    "Swedish" : "瑞典语",
    "Swiss German (Switzerland)" : "瑞士德语（瑞士）",
    "Swiss German" : "瑞士德语",
    "Tachelhit (Latin)" : "Tachelhit语（拉丁文）",
    "Tachelhit (Latin, Morocco)" : "Tachelhit语（拉丁文，摩洛哥）",
    "Tachelhit (Tifinagh)" : "Tachelhit语（提弗纳文）",
    "Tachelhit (Tifinagh, Morocco)" : "Tachelhit语（提弗纳文，摩洛哥）",
    "Tachelhit" : "Tachelhit语",
    "Taita (Kenya)" : "Taita语（肯尼亚）",
    "Taita" : "Taita语",
    "Tamil (India)" : "泰米尔语 （印度）",
    "Tamil (Sri Lanka)" : "泰米尔语（斯里兰卡）",
    "Tamil" : "泰米尔语",
    "Telugu (India)" : "泰卢固语（印度）",
    "Telugu" : "泰卢固语",
    "Teso (Kenya)" : "Teso语（肯尼亚）",
    "Teso (Uganda)" : "Teso语（乌干达）",
    "Teso" : "Teso语",
    "Thai (Thailand)" : "泰语（泰国）",
    "Thai" : "泰语",
    "Tibetan (China)" : "藏语（中国）",
    "Tibetan (India)" : "藏语（印度）",
    "Tibetan" : "藏语",
    "Tigrinya (Eritrea)" : "提格雷语（厄立特里亚）",
    "Tigrinya (Ethiopia)" : "提格雷语（埃塞俄比亚）",
    "Tigrinya" : "提格雷语",
    "Tonga (Tonga)" : "汤加语（汤加）",
    "Tonga" : "汤加语",
    "Turkish (Turkey)" : "土耳其语（土耳其）",
    "Turkish" : "土耳其语",
    "Ukrainian (Ukraine)" : "乌克兰语（乌克兰）",
    "Ukrainian" : "乌克兰语",
    "Urdu (India)" : "乌尔都语（印度）",
    "Urdu (Pakistan)" : "乌尔都语（巴基斯坦）",
    "Urdu" : "乌尔都语",
    "Uzbek (Arabic)" : "乌兹别克语（阿拉伯文）",
    "Uzbek (Arabic, Afghanistan)" : "乌兹别克语（阿拉伯文，阿富汗）",
    "Uzbek (Cyrillic)" : "乌兹别克语（西里尔文）",
    "Uzbek (Cyrillic, Uzbekistan)" : "乌兹别克语（西里尔文，乌兹别克斯坦）",
    "Uzbek (Latin)" : "乌兹别克语（拉丁文）",
    "Uzbek (Latin, Uzbekistan)" : "乌兹别克语（拉丁文，乌兹别克斯坦）",
    "Uzbek" : "乌兹别克语",
    "Vietnamese (Vietnam)" : "越南语（越南）",
    "Vietnamese" : "越南语",
    "Vunjo (Tanzania)" : "Vunjo语（坦桑尼亚）",
    "Vunjo" : "Vunjo语",
    "Welsh (United Kingdom)" : "威尔士语（英国）",
    "Welsh" : "威尔士语",
    "Yoruba (Nigeria)" : "约鲁巴语（尼日利亚）",
    "Yoruba" : "约鲁巴语",
    "Zulu (South Africa)" : "祖鲁语（南非）",
    "Zulu" : "祖鲁语",
    "Store credentials" : "存储凭据",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "cron.php 注册到 webcron 服务上，通过 http 每 15 分钟执行 cron.php。",
    "Use system cron service to call the cron.php file every 15 minutes." : "使用系统定时任务服务每 15 分钟执行一次 cron.php 文件。",
    "Follow us on Google+" : "在 Google+ 上关注我们"
},
"nplurals=1; plural=0;");
